import isystem.connect as ic

import time

# Change these parameters to your configuration
ADIO_NAME = 'ADIO.DIO1'
ADIO_BANK = 0
ADIO_CHANNEL = 0

POWER_CYCLE_DELAY = 2


class ADIO:
    def __init__(self, name: str, bank: int, channel: int) -> None:
        '''
        Class constructor. Establishes connection to most recent used winIDEA. 
        WinIDEA must have debug session established before usage.
            @param name: Name of connected node on FNet network.
            @param bank: ADIO bank which will be used.
            @param channel: ADIO channel which will be used.
        '''

        self.cmgr = ic.ConnectionMgr()

        self.name = name
        self.bank = bank
        self.channel = channel

        self.cmgr.connect()

        self.dbgCtrl = ic.CDebugFacade(self.cmgr)
        self.execCtrl = ic.CExecutionController(self.cmgr)
        self.fnetCtrl = ic.CFNetController(self.cmgr)
        self.dioCtrl = self.fnetCtrl.createDIOController(self.name)

        self.dioCtrl.cfg().setOutputBankConfiguration(self.bank, ic.IOLevels_VL_5V,
                                                      ic.IOState_LOW)
        
        sessionEstablished = not self.dbgCtrl.getCPUStatus().isMustInit()

        if not sessionEstablished:
            self.execCtrl.hotAttach()

    def on(self) -> None:
        '''
        Function turns configured output ON
        '''
        self.dioCtrl.ctrl().setChannelState(self.bank, self.channel, ic.IOState_HIGH)

    def off(self) -> None:
        '''
        Function turns configured output OFF
        '''
        self.dioCtrl.ctrl().setChannelState(self.bank, self.channel, ic.IOState_LOW)

    def close(self) -> None:
        '''
        Closes connection to winIDEA.
        '''
        self.cmgr.disconnect_keep()


if __name__ == '__main__':
    adio = ADIO(ADIO_NAME, ADIO_BANK, ADIO_CHANNEL)

    adio.off()
    time.sleep(POWER_CYCLE_DELAY)
    adio.on()

    adio.close()
