import isystem.connect as ic

import time

# Change these parameters to your configuration
MDIO_NAME = 'Root.mDIO1'
MDIO_CHANNEL = 0

POWER_CYCLE_DELAY = 2


class MDIO:
    def __init__(self, name: str, channel: int) -> None:
        '''
        Class constructor. Establishes connection to most recent used winIDEA. 
        WinIDEA must have debug session established before usage.
            @param name: Name of connected node on FNet network.
            @param channel: MDIO channel which will be used.
        '''

        self.cmgr = ic.ConnectionMgr()

        self.name = name
        self.channel = channel

        self.cmgr.connect()

        self.dbgCtrl = ic.CDebugFacade(self.cmgr)
        self.execCtrl = ic.CExecutionController(self.cmgr)
        self.fnetCtrl = ic.CFNetCtrl(self.cmgr)
        self.dioCtrl = self.fnetCtrl.mDIO_AP(self.name)

        self.dioCtrl.cfg().set_voltage(dVoltage=3.3)
        self.dioCtrl.cfg().set_channel_out(nChannel = self.channel, strName = 'CTRL', bShow = True, bInitialHi = False)

        sessionEstablished = not self.dbgCtrl.getCPUStatus().isMustInit()

        if not sessionEstablished:
            self.execCtrl.hotAttach()

    def on(self) -> None:
        '''
        Function turns configured output ON
        '''
        self.dioCtrl.ctrl_set_channel(self.channel, True)

    def off(self) -> None:
        '''
        Function turns configured output OFF
        '''
        self.dioCtrl.ctrl_set_channel(self.channel, False)

    def close(self) -> None:
        '''
        Closes connection to winIDEA.
        '''
        self.cmgr.disconnect_keep()

if __name__ == '__main__':
    mdio = MDIO(MDIO_NAME, MDIO_CHANNEL)

    mdio.off()
    time.sleep(POWER_CYCLE_DELAY)
    mdio.on()

    mdio.close()